==> python_sdk_remote-0.0.53-py3-none-any.whl: python_sdk_remote/src/validate.py <==
import os

# TODO Rename this file to validate_environment.py similar to what we have in TypeScript


# TODO Align with https://github.com/circles-zone/typescript-sdk-remote-typescript-package/edit/dev/typescript-sdk/src/utils/index.ts validateTenantEnvironmentVariables()  # noqa501
def validate_enviroment_variables():
    validate_brand_name()
    validate_environment_name()
    # if(os.getenv("PRODUCT_USER_IDENTIFIER") is None):
    #     raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called "
    #                     "PRODUCT_USER_IDENTIFIER (instead of PRODUCT_USERNAME)")
    # removed by Idan because it dont has to be in every project
    # if(os.getenv("PRODUCT_PASSWORD") is None):
    #     raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called PRODUCT_PASSWORD")
    validate_logzio_token()


def validate_environment_name():
    if (os.getenv("ENVIRONMENT_NAME") is None):
        raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called "
                        "ENVIRONMENT_NAME=local or play1 (instead of ENVIRONMENT)")


def validate_brand_name():
    if (os.getenv("BRAND_NAME") is None):
        raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called BRAND_NAME=Circlez")


def validate_logzio_token():
    if (os.getenv("LOGZIO_TOKEN") is None):
        raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called"
                        " LOGZIO_TOKEN=cXNHuVkkffkilnkKzZlWExECRlSKqopE")

==> python_sdk_remote-0.0.56-py3-none-any.whl: python_sdk_remote/src/validate.py <==
from .constants import ENVIRONMENT_NAME, LOGZIO_TOKEN, BRAND_NAME

# TODO Rename this file to validate_environment.py similar to what we have in TypeScript


# TODO Align with https://github.com/circles-zone/typescript-sdk-remote-typescript-package/edit/dev/typescript-sdk/src/utils/index.ts validateTenantEnvironmentVariables()  # noqa501
def validate_enviroment_variables():
    validate_brand_name()
    validate_environment_name()
    # if(os.getenv("PRODUCT_USER_IDENTIFIER") is None):
    #     raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called "
    #                     "PRODUCT_USER_IDENTIFIER (instead of PRODUCT_USERNAME)")
    # removed by Idan because it dont has to be in every project
    # if(os.getenv("PRODUCT_PASSWORD") is None):
    #     raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called PRODUCT_PASSWORD")
    validate_logzio_token()


def validate_environment_name():
    if (ENVIRONMENT_NAME is None):
        raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called "
                        "ENVIRONMENT_NAME=local or play1 (instead of ENVIRONMENT)")


def validate_brand_name():
    if (BRAND_NAME is None):
        raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called BRAND_NAME=Circlez")


def validate_logzio_token():
    if (LOGZIO_TOKEN is None):
        raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called"
                        " LOGZIO_TOKEN=cXNHuVkkffkilnkKzZlWExECRlSKqopE")
